==> qtjambi-remoteobjects-debuginfo-windows-x64-5.15.18.jar: sources/QtJambiRemoteObjects/QRemoteObjectDynamicReplica_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtRemoteObjects/qremoteobjectpendingcall.h>
#include <QtRemoteObjects/qremoteobjectreplica.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QRemoteObjectDynamicReplica(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QRemoteObjectDynamicReplica>("QRemoteObjectDynamicReplica", "io/qt/remoteobjects/QRemoteObjectDynamicReplica");
// BEGIN: function table
// END: function table

    registerCustomMetaObject(typeId, QRemoteObjectDynamicReplica::staticMetaObject);
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QRemoteObjectReplica), typeId, [](void *ptr, qintptr& offset) -> bool {
            QRemoteObjectReplica *object = reinterpret_cast<QRemoteObjectReplica *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = dynamic_cast<QRemoteObjectDynamicReplica*>(object);
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-remoteobjects-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiRemoteObjects/QRemoteObjectDynamicReplica_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtRemoteObjects/qremoteobjectdynamicreplica.h>
#include <QtCore/QVariant>
#include <QtRemoteObjects/qremoteobjectnode.h>
#include <QtCore/qbytearray.h>
#include <QtCore/QList>
#include <QtRemoteObjects/qremoteobjectreplica.h>
#include <QtRemoteObjects/qremoteobjectpendingcall.h>
#include <QtCore/qobject.h>
#include <QtCore/qtimer.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qbindingstorage.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qproperty.h>
#include <QtCore/qthread.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QRemoteObjectDynamicReplica(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QRemoteObjectDynamicReplica>("QRemoteObjectDynamicReplica", "io/qt/remoteobjects/QRemoteObjectDynamicReplica");
// BEGIN: function table
// END: function table

    registerCustomMetaObject(typeId, QRemoteObjectDynamicReplica::staticMetaObject);
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QRemoteObjectReplica), typeId, [](void *ptr, qintptr& offset) -> bool {
            QRemoteObjectReplica *object = reinterpret_cast<QRemoteObjectReplica *>(ptr);
            Q_ASSERT(object);
            offset = 0;
            bool _result = false;
            QTJAMBI_TRY_ANY { // cast from baseclass
                _result = dynamic_cast<QRemoteObjectDynamicReplica*>(object);
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
